<?
######## Confixx(R) 3.2.1 Professional ############
####### Copyright SWsoft, Inc. 2004-2006 ##########
##### http://www.swsoft.com - info@swsoft.com #####

$lang_text['__empty_or_not_string'] = 'Empty or not string';
$lang_text['__invalid_interval'] = 'Invalid interval';
$lang_text['ad_from'] = 'Domain';
$lang_text['ad_incorrectdomain'] = '"redirect to" field should not be empty';
$lang_text['ad_incorrectname'] = 'username should not contain @ sign.';
$lang_text['ad_limit'] = 'you can not add new at-domain because you\'ve exceeded limit set up by reseller.';
$lang_text['ad_nameinuse'] = 'that at-domain is already in use.';
$lang_text['ad_noatdomains'] = 'You do not have at domains yet';
$lang_text['ad_summary1'] = 'You have currently $VAR[0] at-domain(s).';
$lang_text['ad_summary2'] = 'You have currently $VAR[0] at-domain(s) of totally $VAR[1] allowed.';
$lang_text['ad_to'] = 'Redirect to';
$lang_text['ad_username'] = 'Prefix';
$lang_text['alfr2_error1'] = 'You are not authorized to use FrontPage';
$lang_text['alfr2_error2'] = 'Please enter a valid e-mail address.';
$lang_text['alfr2_error4'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['alfr2_error5'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['alfr2_error6'] = 'Notice:';
$lang_text['alfr2_error7'] = 'Your data have been saved.';
$lang_text['alfr_btn_send'] = 'Update';
$lang_text['alfr_cell_email'] = 'E-mail address';
$lang_text['alfr_cell_pass'] = 'New password';
$lang_text['alfr_cell_pass2'] = 'Re-enter password';
$lang_text['alfr_cell_url'] = 'URL';
$lang_text['alfr_cell_user'] = 'User';
$lang_text['alfr_desc1'] = 'In addition to your password, you will need the following data for access using FrontPage:';
$lang_text['alfr_desc2'] = 'Notice:';
$lang_text['alfr_desc3'] = 'Only enter a new password if you want to change the password. The e-mail address will be used as the sender\'s address when using FrontPage e-mail forms.';
$lang_text['alfr_error1'] = 'You are not authorized to use FrontPage.';
$lang_text['alfr_title'] = 'FrontPage';
$lang_text['alpw2_error1'] = 'The old password does not match the password on file. Please complete the form again.';
$lang_text['alpw2_error3'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['alpw2_error4'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['alpw2_error5'] = 'Notice:';
$lang_text['alpw2_error6'] = 'Your password has been changed.';
$lang_text['alpw_btn_change'] = 'Change password';
$lang_text['alpw_cell_new'] = 'New password';
$lang_text['alpw_cell_old'] = 'Old password';
$lang_text['alpw_cell_repeat'] = 'Re-enter password';
$lang_text['alpw_cell_stats'] = 'Change for stats, too';
$lang_text['alpw_desc1'] = 'Please complete the entire form and confirm by clicking on &quot;Change password&quot;.';
$lang_text['alpw_desc2'] = 'You can use this password to log onto this interface and to the server using FTP.';
$lang_text['alpw_title'] = 'Change password';
$lang_text['alse2_cell_message'] = 'Message';
$lang_text['alse2_cell_time'] = 'Time';
$lang_text['alse2_error1'] = 'No messages available.';
$lang_text['alse2_link_back'] = 'back';
$lang_text['alse2_link_forward'] = 'forward';
$lang_text['alse2_link_selection'] = 'Selection';
$lang_text['alse2_noerrormessages'] = 'There are no error messages at the moment.';
$lang_text['alse2_noerrors'] = 'There are no errors at the moment.';
$lang_text['alse2_nohints'] = 'There are no notices at the moment.';
$lang_text['alse2_text_error'] = 'Error';
$lang_text['alse2_text_hints'] = 'Notices:';
$lang_text['alse2_title1'] = 'Messages';
$lang_text['alse2_title2'] = 'Messages';
$lang_text['alse_button1'] = 'Show';
$lang_text['alse_cell_messagecount'] = 'Number of messages';
$lang_text['alse_cell_messagetype'] = 'Type';
$lang_text['alse_cell_type'] = 'Type';
$lang_text['alse_descr1'] = 'In this section you can call up messages that have been issued by Confixx for your activities.';
$lang_text['alse_descr2'] = '<b><i>Error:</i></b><br>Error messages are generated, for example, if a directory did not exist or if it could not be deleted.';
$lang_text['alse_descr3'] = '<b><i>Notices:</i></b><br>Notices are used for logging. They are generated when e-mail addresses, sub-domains etc., have been created or deleted.';
$lang_text['alse_select_error'] = 'Error';
$lang_text['alse_select_hint'] = 'Notices';
$lang_text['alse_title1'] = 'Messages';
$lang_text['alse_title2'] = 'There are two types of messages:';
$lang_text['alsp2_error1'] = 'Invalid language selection. The language has not been changed.';
$lang_text['alsp_button1'] = 'Change';
$lang_text['alsp_cell_language'] = 'Language';
$lang_text['alsp_descr1'] = 'Select a language for your Confixx web interface.';
$lang_text['alsp_error1'] = 'You are logged in as $VAR[0] and you have changed language/design for user $VAR[1] but the change will not affect language/design you are using now. To change effective language/design go to $VAR[0] panel and change it there.';
$lang_text['alsp_title1'] = 'Language';
$lang_text['alst_activated'] = 'Activated';
$lang_text['alst_cell_address'] = 'Address';
$lang_text['alst_cell_atdomains'] = 'At-domains';
$lang_text['alst_cell_autoresponder'] = 'E-mail autoresponders';
$lang_text['alst_cell_cgiperl'] = 'CGI/Perl outside cgi-bin';
$lang_text['alst_cell_cid'] = 'Customer ID';
$lang_text['alst_cell_city'] = 'ZIP &amp; City';
$lang_text['alst_cell_cron'] = 'Cron jobs';
$lang_text['alst_cell_dirlist'] = 'Directory listing';
$lang_text['alst_cell_domains'] = 'Domain(s)';
$lang_text['alst_cell_du'] = 'Storage space';
$lang_text['alst_cell_email'] = 'E-mail addresses';
$lang_text['alst_cell_fax'] = 'Fax';
$lang_text['alst_cell_features'] = 'Active services';
$lang_text['alst_cell_firm'] = 'Company';
$lang_text['alst_cell_ftp'] = 'FTP accounts';
$lang_text['alst_cell_idn'] = 'National domains';
$lang_text['alst_cell_link1'] = 'change';
$lang_text['alst_cell_login'] = 'Username';
$lang_text['alst_cell_maillist'] = 'Mailing lists';
$lang_text['alst_cell_mysql'] = 'MySQL databases';
$lang_text['alst_cell_name'] = 'Name';
$lang_text['alst_cell_pop3'] = 'POP3 boxes';
$lang_text['alst_cell_scponly'] = 'Scp/SFTP';
$lang_text['alst_cell_scponly_active'] = 'Activated';
$lang_text['alst_cell_shell'] = 'Shell access';
$lang_text['alst_cell_shell_active'] = 'Activated';
$lang_text['alst_cell_subdomain'] = 'Sub-domains';
$lang_text['alst_cell_tel'] = 'Telephone';
$lang_text['alst_cell_traffic'] = 'Traffic';
$lang_text['alst_deactivated'] = 'Deactivated';
$lang_text['alst_descr1'] = 'Confixx - The Interface for Web Servers';
$lang_text['alst_descr2'] = 'The values in parentheses represent the maximum you may define or use.';
$lang_text['alst_title1'] = 'General information';
$lang_text['alst_title2'] = 'User data';
$lang_text['alst_title3'] = 'Service overview';
$lang_text['altr_cell_day'] = 'Day';
$lang_text['altr_cell_email'] = 'E-mail';
$lang_text['altr_cell_ftpweb'] = 'FTP / WEB';
$lang_text['altr_cell_month'] = 'Month';
$lang_text['altr_cell_total'] = 'Total';
$lang_text['altr_desc'] = 'This displays traffic generated by your activities on the server, which has been measured by Confixx.';
$lang_text['altr_details'] = 'Transfer details for';
$lang_text['altr_summary'] = 'Transfer summary for all months';
$lang_text['altr_title'] = 'Your traffic';
$lang_text['alwe_awstats'] = 'Call up AWstats';
$lang_text['alwe_desc'] = 'In general, username and password for the access stats are identical with your user data for access';
$lang_text['alwe_stats'] = 'Call up access stats';
$lang_text['alwe_title'] = 'Access stats';
$lang_text['alwe_userpass'] = 'User &amp; password for access stats';
$lang_text['alwepw1_btn_change'] = 'Change password';
$lang_text['alwepw1_cell_pass1'] = 'New password';
$lang_text['alwepw1_cell_pass2'] = 'Re-enter password';
$lang_text['alwepw1_desc2'] = 'Please complete the entire form and confirm by clicking on &quot;Change password&quot;.';
$lang_text['alwepw1_desc3'] = 'You can use this password to log onto the access stats.';
$lang_text['alwepw1_title'] = 'Access stats';
$lang_text['alwepw2_error2'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['alwepw2_error3'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['alwepw2_error4'] = 'You are not authorized to make these settings.';
$lang_text['alwepw2_error5'] = 'Notice:';
$lang_text['alwepw2_error6'] = 'Your password has been changed.';
$lang_text['awstats_noconfig'] = 'AWstats has not yet been configured for user $VAR[0]';
$lang_text['cron_cmd'] = 'Command';
$lang_text['cron_confirm_refuse_changes'] = 'You still have some changes in cron jobs not sumitted yet. 
Do you want your changes to be lost and to read cron jobs from the system?';
$lang_text['cron_confirm_refuse_reread'] = 'Rereading cron jobs from the system was not complete yet. 
Do you want to overwrite your existing crontab records?';
$lang_text['cron_day_of_month'] = 'Day of month';
$lang_text['cron_day_of_week'] = 'Day of week';
$lang_text['cron_delete'] = 'delete';
$lang_text['cron_delete_quest'] = 'Are you sure you want to delete the cronjob?';
$lang_text['cron_desc1'] = 'Here you can add/delete/edit cron jobs.<br><br>If you want to add a new job, click &quot;<b>New job</b>&quot;.<br><br>You can also edit or delete a job previously created by using the corresponding links in the jobs list.<br><br>If you have done some modifications in crontab from outside the Confixx Control Panel (e.g. using shell access), you can make your modifications available in the Control Panel using the &quot;<b>Reread list</b>&quot; button.';
$lang_text['cron_desc2'] = 'The format of date/time fields conforms to those described in the man-pages for crontab(5) except for the support of symbolic names for months and days of week - the Control Panel does not support them. Ranges, lists, steps are supported.<br><br> The &quot;<b>Command</b>&quot; field may contain any valid shell - command.';
$lang_text['cron_desc_title'] = 'Cron jobs management.';
$lang_text['cron_edit'] = 'edit';
$lang_text['cron_hour'] = 'Hour';
$lang_text['cron_limit_error'] = 'You cannot create a cronjob, because this action will exceed the defined limit ($VAR[0] cronjob(s)).';
$lang_text['cron_minute'] = 'Minute';
$lang_text['cron_month'] = 'Month';
$lang_text['cron_new_job'] = 'New job';
$lang_text['cron_reread'] = 'Reread list';
$lang_text['cron_reread_note'] = 'Cron jobs list will be updated the next time the update script is executed.';
$lang_text['dbmy_button1'] = 'Create';
$lang_text['dbmy_cell_action'] = 'Action';
$lang_text['dbmy_cell_comment'] = 'Comment';
$lang_text['dbmy_cell_commentfield'] = 'Comment field (optional)';
$lang_text['dbmy_cell_db'] = 'Database';
$lang_text['dbmy_cell_dbadd'] = 'Create new database';
$lang_text['dbmy_cell_dbdel'] = 'Delete database';
$lang_text['dbmy_cell_status'] = 'Status';
$lang_text['dbmy_desc1'] = 'You are currently using <b>$VAR[0]</b> of a total of <b>$VAR[1]</b> possible databases.';
$lang_text['dbmy_desc2'] = 'The username to access your MySQL database is &quot;$VAR[0]&quot;. You can change your password <a class=data href="db_mysql_pwaendern.php">here</a>.';
$lang_text['dbmy_desc2a'] = 'The username to access your MySQL database is &quot;$VAR[0]&quot;.';
$lang_text['dbmy_desc3'] = '<a class=data href="db_mysql_anlegen.php">Click here</a>, to create another database.';
$lang_text['dbmy_desc4'] = 'You are currently using <b>$VAR[0]</b> of a total of <b>unlimited</b> possible databases.';
$lang_text['dbmy_link_change'] = 'Change';
$lang_text['dbmy_nodb'] = 'You have no databases';
$lang_text['dbmy_nodb_selected'] = 'You have not select any database.';
$lang_text['dbmy_password'] = 'Change password';
$lang_text['dbmy_state_external'] = 'external';
$lang_text['dbmy_state_local'] = 'local';
$lang_text['dbmy_title'] = 'MySQL Databases';
$lang_text['dbmyan_error1'] = 'You have reached the maximum number of MySQL databases. You cannot create any more databases.';
$lang_text['dbmyan_error2'] = 'Unable to determine an available database name. Please try again.';
$lang_text['dbmyan_error3'] = 'Database &quot;<b>$VAR[0]</b>&quot; has been created. You can access it using MySQL user &quot;<b>$VAR[1]</b>&quot;. Please use the host &quot;<b>$VAR[2]</b>&quot;.';
$lang_text['dbmyan_error4'] = 'Database &quot;<b>$VAR[0]</b>&quot; has been created. You can access it using MySQL user &quot;<b>$VAR[1]</b>&quot;. Please use the host &quot;<b>$VAR[2]</b>&quot;. Your password is &quot;<b>$VAR[3]</b>&quot;.';
$lang_text['dbmyan_error_create'] = 'Can\'t create database';
$lang_text['dbmyan_errortitle'] = 'Notice:';
$lang_text['dbmyan_errortitle1'] = 'Error:';
$lang_text['dbmylo2_error1'] = 'MySQL database &quot;<b>$VAR[0]</b>&quot; has been deleted.';
$lang_text['dbmylo2_error2'] = 'MySQL database &quot;<b>$VAR[0]</b>&quot; has been deleted. The user for access to the database is no longer needed and has also been deleted.';
$lang_text['dbmylo2_errortitle'] = 'Notice:';
$lang_text['dbmylo_back'] = 'Back';
$lang_text['dbmylo_btn_del'] = 'Delete database';
$lang_text['dbmylo_desc'] = 'Do you really want to delete the MySQL database <b>$VAR[0]</b> and its entire contents?';
$lang_text['dbmylo_title'] = 'Delete MySQL database';
$lang_text['dbmypw2_error2'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['dbmypw2_error3'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['dbmypw2_error4'] = 'Notice:';
$lang_text['dbmypw2_error5'] = 'The password for your MySQL user has been changed.';
$lang_text['dbmypw_btn_change'] = 'Change password';
$lang_text['dbmypw_cell_pass1'] = 'New password';
$lang_text['dbmypw_cell_pass2'] = 'Re-enter password';
$lang_text['dbmypw_cell_username'] = 'MySQL username';
$lang_text['dbmypw_desc'] = 'Please complete the entire form and confirm by clicking on &quot;Change password&quot;.';
$lang_text['dbmypw_title'] = 'Change password for MySQL database';
$lang_text['dbst_cell_host'] = 'Host:';
$lang_text['dbst_cell_pass'] = 'Password:';
$lang_text['dbst_cell_user'] = 'User:';
$lang_text['dbst_desc1'] = 'Use this section to manage your databases. Here you can create and delete databases and change passwords.';
$lang_text['dbst_desc2'] = 'In addition, PhpMyAdmin can be used to manage your MySQL databases.';
$lang_text['dbst_desc3'] = 'To access the MySQL console using Telnet/SSH, you must log onto the server with an SSH or Telnet client. Please use the following data:';
$lang_text['dbst_title'] = 'Databases';
$lang_text['eiht_button1'] = 'Next';
$lang_text['eiht_cell_additionalentries'] = 'httpd additional entries for';
$lang_text['eiht_cell_all_domains'] = 'change all domains';
$lang_text['eiht_cell_domain'] = 'change a domain';
$lang_text['eiht_cell_title1'] = 'Please select an action';
$lang_text['eiht_title1'] = 'Change special httpd entries';
$lang_text['eihtdo_cell_domain'] = 'Domain';
$lang_text['eihtdoae_button1'] = 'save';
$lang_text['eihtdoaesp_error1'] = 'The data has been saved.';
$lang_text['eihtdoaesp_errortitle'] = 'Notice:';
$lang_text['eihtdosu_cell_domain'] = 'Domain';
$lang_text['eihtdosu_cell_select'] = 'select';
$lang_text['eihtfw_error1'] = 'Please select an action.';
$lang_text['eihtkuae_cell_text3'] = 'set for all user domains to be created in the future';
$lang_text['eihtkuae_cell_title1'] = 'change additional httpd entry for $VAR[0]';
$lang_text['eihtkuaesp_error1'] = 'The data has been saved.';
$lang_text['eihtkuaesp_error2'] = '<br>The following domains have not been changed:<br><br>';
$lang_text['eihtkuaesp_errortitle1'] = 'Notice:';
$lang_text['emau2_btn_del'] = 'Delete now.';
$lang_text['emau2_btn_new'] = 'Create';
$lang_text['emau2_btn_save'] = 'Save';
$lang_text['emau2_cell_sender1'] = 'Sender\'s e-mail address';
$lang_text['emau2_cell_sender2'] = 'Name of sender';
$lang_text['emau2_cell_subject'] = 'Subject';
$lang_text['emau2_cell_text'] = 'Text';
$lang_text['emau2_cell_title'] = 'Autoresponder for';
$lang_text['emau2_cell_title2'] = 'Delete autoresponder for $VAR[0]';
$lang_text['emau2_cell_title_text1'] = 'edit';
$lang_text['emau2_cell_title_text2'] = 'create';
$lang_text['emau2_desc1'] = 'Please complete the following form to edit your autoresponder or set up a new autoresponder.';
$lang_text['emau2_desc2'] = 'Leave &quot;Subject&quot; blank so that the subject of the e-mail to be responded to will be inserted.';
$lang_text['emau2_error1'] = 'You have reached the maximum number of e-mail autoresponders. You cannot set up any more e-mail autoresponders.';
$lang_text['emau2_title'] = 'E-mail autoresponders';
$lang_text['emau3_error1'] = 'Please enter a text.';
$lang_text['emau3_error2'] = 'Please enter the name of the sender.';
$lang_text['emau3_error3'] = 'Please enter the e-mail address of the sender.';
$lang_text['emau3_error4'] = 'You have reached the maximum number of e-mail autoresponders. You cannot set up any more e-mail autoresponders.';
$lang_text['emau3_error5'] = 'Your autoresponder has been set up.';
$lang_text['emau3_errortitle'] = 'Notice:';
$lang_text['emau_autoresponder_note'] = 'Please, use for configure autoresponders WebMail interface (Settings->Autoresponders)';
$lang_text['emau_btn_new'] = 'Edit / new';
$lang_text['emau_cell_autoresp'] = 'Autoresponders';
$lang_text['emau_cell_email'] = 'E-mail address';
$lang_text['emau_desc1'] = 'An e-mail autoresponder automatically responds to any e-mails received by a specific e-mail address with a text that you have specified.';
$lang_text['emau_desc2'] = 'Please select an e-mail address for which you want to create or edit an autoresponder. All e-mail addresses marked with an * have been set up with an autoresponder.';
$lang_text['emau_desc3'] = 'You have already set up <b>$VAR[0]</b> e-mail autoresponders of a total of <b>$VAR[1]</b> possible e-mail autoresponders.';
$lang_text['emau_desc4'] = 'You must create at least one e-mail address before you can set up an autoresponder.';
$lang_text['emau_title'] = 'E-mail autoresponders';
$lang_text['emaulo_error1'] = 'Notice:';
$lang_text['emaulo_error2'] = 'Your autoresponder has been deleted.';
$lang_text['emem_autoresp_switch_off'] = 'Autoresponder is on for the e-mail. Click to change autoresponder.';
$lang_text['emem_autoresp_switch_on'] = 'Autoresponder is off for the e-mail. Click to change autoresponder.';
$lang_text['emem_btn_add'] = 'Add';
$lang_text['emem_cell_action'] = 'Action';
$lang_text['emem_cell_alias'] = 'Existing e-mail';
$lang_text['emem_cell_autorsp_state'] = 'A';
$lang_text['emem_cell_drweb'] = 'DrWeb settings';
$lang_text['emem_cell_email'] = 'E-mail address';
$lang_text['emem_cell_emailname'] = 'Mail name';
$lang_text['emem_cell_newmail'] = 'New e-mail address';
$lang_text['emem_cell_pop3'] = 'POP3 box';
$lang_text['emem_cell_recipient'] = 'Recipient';
$lang_text['emem_cell_status'] = 'S';
$lang_text['emem_cell_to'] = 'Forward to';
$lang_text['emem_confirm_delete'] = 'Would you like to delete this e-mail address?';
$lang_text['emem_desc1'] = 'In this section you can set up your e-mail addresses. You must decide whether you want to have your e-mails forwarded to an existing e-mail address (e.g., with your provider) or to a POP3 box.';
$lang_text['emem_desc2'] = 'If you want to receive e-mails that were sent to an e-mail address that you have not set up here, simply create the e-mail address(es) <b>*@domain.de to</b> for your domain(s). This e-mail address will receive any e-mails sent to your domain(s), regardless of what precedes the <b>@-symbol</b>.';
$lang_text['emem_desc3'] = 'You have already set up <b>$VAR[0]</b> e-mail addresses of a total of <b>$VAR[1]</b> possible e-mail addresses.';
$lang_text['emem_drweb_filter'] = 'filter';
$lang_text['emem_drweb_notify'] = 'notify';
$lang_text['emem_link_del'] = 'delete';
$lang_text['emem_link_edit'] = 'edit';
$lang_text['emem_nodomain'] = 'To create an e-mail address you must have at least one domain.';
$lang_text['emem_noemail'] = 'You have not yet set up an e-mail address.';
$lang_text['emem_status_new'] = 'new';
$lang_text['emem_status_normal'] = 'ok';
$lang_text['emem_status_todelete'] = 'deleted';
$lang_text['emem_subtitle1'] = 'The following e-mail addresses have been set up:';
$lang_text['emem_subtitle2'] = 'Add new e-mail address';
$lang_text['emem_subtitle3'] = 'Add new forwarder';
$lang_text['emem_title'] = 'E-mail addresses';
$lang_text['ememan2_error1'] = 'You have reached the maximum number of e-mail addressess. You cannot set up any more e-mail addresses.';
$lang_text['ememan2_error2'] = 'The e-mail address to forward the e-mails to is invalid.';
$lang_text['ememan2_error3'] = 'The domain &quot;<b>$VAR[0]</b>&quot; already exists or does not belong to you.';
$lang_text['ememan2_error4'] = 'Your e-mail address must consist of at least six character and may only consist of letters, numbers and the special characters <b>-</b> and <b>_</b> and <b>%</b> as well as periods. Special characters may not be placed at the beginning or at the end of the e-mail address.';
$lang_text['ememan2_error5'] = 'The e-mail address &quot;<b>$VAR[0]</b>&quot; already exists.';
$lang_text['ememan2_error6'] = 'The target e-mail address is a forwarder. You cannot forward e-mails to forwarders. Please enter a different e-mail address.';
$lang_text['ememan2_error7'] = 'Notice:';
$lang_text['ememan2_error8'] = 'The e-mail address &quot;<b>$VAR[0]</b>&quot; has been set up.';
$lang_text['ememan_error1'] = 'You have reached the maximum number of e-mail addresses. You cannot set up any more e-mail addresses.';
$lang_text['ememan_error10'] = 'Unable to set up the e-mail address because it is reserved.';
$lang_text['ememan_error2'] = 'The domain &quot;<b>$domain</b>&quot; does not exist or does not belong to you.';
$lang_text['ememan_error3'] = 'Your e-mail address must consist of at least one character and may only consist of letters, numbers and the special characters <b>-</b> and <b>_</b> and <b>%</b> as well as periods. Special characters may not be placed at the beginning or at the end of the e-mail address.';
$lang_text['ememan_error4'] = 'The e-mail address &quot;<b>$VAR[0]</b>&quot; with forward target &quot;<b>$VAR[1]</b>&quot; already exists.';
$lang_text['ememan_error5'] = 'The POP3 box &quot;<b>$VAR[0]</b>&quot; already exists or does not belong to you.';
$lang_text['ememan_error6'] = 'Notice:';
$lang_text['ememan_error7'] = 'The e-mail address &quot;<b>$VAR[0]</b>&quot; has been set up.';
$lang_text['ememan_error8'] = 'Unable to set up e-mail address. This mail name conficts with an existing mailing list: <b>$VAR[0]</b>';
$lang_text['ememan_error9'] = 'You can\'t create wildcard email on shared domain.';
$lang_text['ememan_error_exist'] = 'The e-mail address &quot;<b>$VAR[0]</b>&quot; already exists or does not belong to you.';
$lang_text['emembe2_error1'] = 'The main recipient is a forwarder. You cannot forward e-mails to forwarders. Please enter a different e-mail address.';
$lang_text['emembe2_error2'] = 'Incorrect format of main recipient\'s e-mail address.';
$lang_text['emembe2_error3'] = 'Please enter a main recipient.';
$lang_text['emembe2_error4'] = 'Notice:';
$lang_text['emembe2_error5'] = 'The e-mail address &quot;<b>$VAR[0]</b>&quot; has been changed. At least one target e-mail address is a forwarder to a forwarder. This is not authorized. The apprpriate target e-mail addresses have not been entered.';
$lang_text['emembe2_error6'] = 'The e-mail address &quot;<b>$VAR[0]</b>&quot; has been changed.';
$lang_text['emembe2_error7'] = 'At least one other target e-mail address had an incorrect format and has not been saved.';
$lang_text['emembe_button1'] = 'Apply changes';
$lang_text['emembe_cell_recpt1'] = 'Main recipient';
$lang_text['emembe_cell_recpt2'] = 'Additional recipient';
$lang_text['emembe_cell_redirect'] = 'redirect to';
$lang_text['emembe_cell_save'] = 'save in';
$lang_text['emembe_title'] = 'Edit list of recipients';
$lang_text['ememlo_error1'] = 'Notice:';
$lang_text['ememlo_error2'] = 'The e-mail address has been deleted.';
$lang_text['emfo_error1'] = 'Could not create new folder: $VAR[0]';
$lang_text['emfo_error2'] = 'Could not delete folder: $VAR[0]';
$lang_text['empo_button1'] = 'create';
$lang_text['empo_cell_action'] = 'Action';
$lang_text['empo_cell_comment'] = 'Comment';
$lang_text['empo_cell_commentfield'] = 'Comment field (optional)';
$lang_text['empo_cell_diskusage'] = 'Disk Usage';
$lang_text['empo_cell_hardquota'] = 'Hard quota';
$lang_text['empo_cell_newpop'] = 'Set up new POP3 box';
$lang_text['empo_cell_pop3'] = 'POP3 box';
$lang_text['empo_cell_softquota'] = 'Soft quota';
$lang_text['empo_cell_specify_password'] = 'Specify password';
$lang_text['empo_cell_status'] = 'S';
$lang_text['empo_desc1'] = 'A POP3 box is similar to a mailbox. Received e-mails are saved in your POP3 box. You will need at least one POP3 box when you set up an e-mail address so that you will be able to retrieve your e-mails using this POP3 box. If you have an existing e-mail address (e.g., with your provider), you can have your e-mails forwarded to that e-mail address as well. In this case you do not need to set up a POP3 box.';
$lang_text['empo_desc2'] = 'You have already set up <b>$VAR[0]</b> POP3 boxes of a total of <b>$VAR[1]</b> possible POP3 boxes.';
$lang_text['empo_link_change'] = 'change';
$lang_text['empo_link_del'] = 'delete';
$lang_text['empo_title'] = 'POP3 boxes';
$lang_text['empoan_error1'] = 'You have reached the maximum number of POP3 boxes. You cannot set up any more POP3 boxes.';
$lang_text['empoan_error2'] = 'The POP3 box could not be set up because the account name could not be determined. Please try again.';
$lang_text['empoan_error3'] = 'Notice:';
$lang_text['empoan_error4'] = 'The POP3 box &quot;<b>$VAR[0]</b>&quot; has been set up. Your password is &quot;<b>$VAR[1]</b>&quot;. With this POP3 box and your password, you can log onto the Confixx interface, change your password and use WebMail.';
$lang_text['empoan_error_mailspace'] = 'You do not have enough mail space for new POP3 boxes.';
$lang_text['empoan_error_mailspace_2'] = 'Can\'t create new POP3 box with $VAR[0] size: you have only $VAR[1] free mail space.You have not enough of mail space for new POP3 boxes.';
$lang_text['empolo2_error1'] = 'This POP3 box does not exist.';
$lang_text['empolo2_error2'] = 'Notice:';
$lang_text['empolo2_error3'] = 'POP3 box &quot;<b>$VAR[0]</b>&quot; has been deleted.';
$lang_text['empolo_btn'] = 'Delete mail box';
$lang_text['empolo_desc'] = 'Are you sure that you want to delete POP3 box &quot;$VAR[0]&quot;? Any e-mails in this mail box will be lost. The following e-mail addresses are linked to this mail box and will also be deleted:';
$lang_text['empolo_desc2'] = 'This POP3-Account will be deleted from the list of additional recipients of the following e-mail addresses:';
$lang_text['empolo_link'] = 'Back';
$lang_text['empolo_title'] = 'Delete POP3 box';
$lang_text['empopw2_error2'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['empopw2_error3'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['empopw2_error4'] = 'Notice:';
$lang_text['empopw2_error5'] = 'Your data have been saved.';
$lang_text['empopw_btn_change'] = 'Save data';
$lang_text['empopw_cell_comment'] = 'Comment field (optional)';
$lang_text['empopw_cell_pop3'] = 'POP3 box';
$lang_text['empopw_cell_pw1'] = 'New password';
$lang_text['empopw_cell_pw2'] = 'Re-enter password';
$lang_text['empopw_desc'] = 'Please fill in this form and confirm with &quot;Save data&quot;. If you do not want to change your user name, please leave the password fields blank.';
$lang_text['empopw_title'] = 'Change POP3 box data';
$lang_text['empty_trash'] = 'Empty trash';
$lang_text['emquch_error2'] = 'The hard quota must be more then the soft quota.';
$lang_text['emquch_error3'] = 'You have only $VAR[0] KB mail space left to assign.';
$lang_text['emquch_error4'] = 'You can not set unlimited hard quota';
$lang_text['emquch_error5'] = 'You have set up unlimited default quota having $VAR[0]  mailspace limit, you will not be able to create a POP3 box with the settings';
$lang_text['emquch_error6'] = 'You have $VAR[0] mailspace limit, you can not set up POP3 box with unlimited(0) quota.';
$lang_text['emquch_hard'] = 'Hard quota';
$lang_text['emquch_soft'] = 'Soft quota';
$lang_text['emquch_title'] = 'Mail quota';
$lang_text['emst_desc1'] = 'You have two options when setting up an e-mail address:';
$lang_text['emst_desc2'] = 'Forward to an existing e-mail address';
$lang_text['emst_desc3'] = '(e.g., with your provider)';
$lang_text['emst_desc4'] = 'Forward to a POP3 box';
$lang_text['emst_desc5'] = 'E-mails are saved in your POP3 box on this server until you retrieve them with your e-mail program.';
$lang_text['emst_desc6'] = 'If you want your e-mails to be forwarded to a POP3 box, you must first set up a <a class=data href="email_pop3.php">POP3 box</a>.';
$lang_text['emst_desc7'] = 'You can specify autoresponders, that is automatic responses, for your e-mail addresses. They are useful, for example, if you are unable to retrieve your e-mails for a longer period of time.';
$lang_text['emst_title'] = 'E-mail addresses';
$lang_text['err_hacker'] = 'You are hacker?';
$lang_text['err_invaliduser'] = 'Invalid user';
$lang_text['err_system'] = 'System error';
$lang_text['ftp_alpw2_error1'] = 'The old password does not match the password on file. Please complete the form again.';
$lang_text['ftp_alpw2_error3'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['ftp_alpw2_error4'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['ftp_alpw2_error5'] = 'Your password has been changed.';
$lang_text['ftp_alpw2_errortitle'] = 'Notice:';
$lang_text['ftp_alpw_button1'] = 'Change password';
$lang_text['ftp_alpw_cell_newpw1'] = 'New password';
$lang_text['ftp_alpw_cell_newpw2'] = 'Re-enter password';
$lang_text['ftp_alpw_cell_oldpw'] = 'Old password';
$lang_text['ftp_alpw_descr1'] = 'Please complete the entire form below and confirm by clicking on &quot;Change password&quot;.';
$lang_text['ftp_alpw_title'] = 'Change password';
$lang_text['ftp_alsp2_error1'] = 'Invalid language selection. The language has not been changed.';
$lang_text['ftp_alsp_button1'] = 'Change';
$lang_text['ftp_alsp_descr1'] = 'Select a language for your Confixx web interface.';
$lang_text['ftp_alsp_title1'] = 'Language';
$lang_text['ftp_alst_button1'] = 'Go WebFTP';
$lang_text['ftp_alst_descr1'] = 'Click on the button below to go to WebFTP.';
$lang_text['ftp_alst_title'] = 'WebFTP &quot;$VAR[0]&quot;';
$lang_text['ftp_file_not_exists'] = 'not exists';
$lang_text['ftp_no_connect'] = 'Can\'t connenct to server \'$VAR[0]\'';
$lang_text['ftp_no_login'] = 'Can\'t login to server \'$VAR[0]\' as user \'$VAR[1]\'';
$lang_text['g_error'] = 'Error';
$lang_text['g_light'] = '<P><font face="Arial, Helvetica, sans-serif" size="-1"><b>This feature is not available in Confixx-Light.</b></font></P>';
$lang_text['g_listsize'] = 'List size';
$lang_text['g_next'] = '[&gt;&nbsp;next]';
$lang_text['g_no'] = 'No';
$lang_text['g_nolimit'] = 'Unlimited';
$lang_text['g_prev'] = '[&lt;&nbsp;prev]';
$lang_text['g_save'] = 'Save';
$lang_text['g_title'] = 'Confixx&reg; - Server Administration';
$lang_text['g_yes'] = 'Yes';
$lang_text['httpd_options_do_not_change'] = 'Do not change';
$lang_text['idn_add'] = 'Add';
$lang_text['idn_delete'] = 'Delete';
$lang_text['idn_delquest'] = 'Delete selected domains?';
$lang_text['idn_edit'] = 'edit';
$lang_text['idn_err_baddomain'] = 'Invalid domain name';
$lang_text['idn_err_domainalready'] = 'Domain already exists';
$lang_text['idn_err_maxidn'] = 'You have reached the maximum number of national domains. You cannot set up any more national domains.';
$lang_text['idn_havend'] = 'You have already set up <b>$VAR[0]</b> national domains of a total of <b>$VAR[1]</b> possible national domains.';
$lang_text['idn_nationaldomain'] = 'National domain name (alias)';
$lang_text['idn_origdomain'] = 'Original domain';
$lang_text['ll_state_off'] = 'off';
$lang_text['ll_state_on'] = 'on';
$lang_text['ls_error'] = 'Incorrect List Size value. Use positive integers only.';
$lang_text['m_adbook'] = 'Address book';
$lang_text['m_backup'] = 'Backup';
$lang_text['m_backup_opts'] = 'Backup Settings';
$lang_text['m_cron'] = 'Crontab';
$lang_text['m_db'] = 'Databases';
$lang_text['m_email'] = 'E-mail';
$lang_text['m_emailneu'] = 'New email';
$lang_text['m_folder'] = 'Folder';
$lang_text['m_folder_list'] = 'Folder list';
$lang_text['m_folder_name'] = 'Folder name';
$lang_text['m_folders'] = 'Folders';
$lang_text['m_folders_inbox'] = 'Inbox';
$lang_text['m_ftp'] = 'Ftp';
$lang_text['m_general'] = 'General';
$lang_text['m_help'] = 'Confixx help';
$lang_text['m_idn'] = 'National aliases';
$lang_text['m_login'] = 'Log on again';
$lang_text['m_maillist'] = 'Mailing lists';
$lang_text['m_message'] = 'Message';
$lang_text['m_move_to'] = 'Move to $VAR[0]';
$lang_text['m_move_to_error0'] = 'Error: the Folder where the email will be moved is not selected';
$lang_text['m_overview'] = 'Overview';
$lang_text['m_postfach'] = 'Message list';
$lang_text['m_restore'] = 'Restore';
$lang_text['m_settings'] = 'Settings';
$lang_text['m_spam'] = 'Spam filter';
$lang_text['m_tools'] = 'Tools';
$lang_text['m_webapp'] = 'Software Center';
$lang_text['m_wftp_home'] = 'Home Path';
$lang_text['m_wftp_mkdir'] = 'Create Directory';
$lang_text['m_wftp_new'] = 'Create Text File';
$lang_text['m_wftp_path'] = 'Current Path';
$lang_text['m_wftp_refresh'] = 'Refresh';
$lang_text['m_wftp_upload'] = 'Upload File';
$lang_text['ma_changepw'] = 'Change password';
$lang_text['ma_frontpage'] = 'FrontPage';
$lang_text['ma_selectlanguage'] = 'Language';
$lang_text['ma_servermessages'] = 'Messages';
$lang_text['ma_stats'] = 'Access stats';
$lang_text['ma_traffic'] = 'Traffic';
$lang_text['mail_space_def'] = 'Mail quota defaults';
$lang_text['md_mysql'] = 'MySQL';
$lang_text['md_phpmyadmin'] = 'PhpMyAdmin';
$lang_text['me_autoresponder'] = 'Autoresponders';
$lang_text['me_email'] = 'E-mail addresses';
$lang_text['me_mailquota'] = 'Mail quota';
$lang_text['me_pop3'] = 'POP3 boxes';
$lang_text['mftp_changepw'] = 'Change password';
$lang_text['mftp_selectlanguage'] = 'Language';
$lang_text['ml_add'] = 'Add';
$lang_text['ml_cell_status'] = 'S';
$lang_text['ml_change'] = 'Change maillist <b>$VAR[0]</b>';
$lang_text['ml_changepass'] = 'change password';
$lang_text['ml_confirmpassword'] = 'Confirm password';
$lang_text['ml_delete'] = 'Delete';
$lang_text['ml_delquest'] = 'Delete selected mailing lists?';
$lang_text['ml_domain'] = 'Domain';
$lang_text['ml_err_alreadymaillist'] = 'The mailing list "<b>$VAR[0]</b>" already exists.';
$lang_text['ml_err_emailconflict'] = 'There is a conflict with an existing email: <b>$VAR[0]</b>.';
$lang_text['ml_err_emptymaillist'] = 'Empty mailing list name';
$lang_text['ml_err_emptypass'] = 'Empty password';
$lang_text['ml_err_invalidemail'] = 'Invalid e-mail';
$lang_text['ml_err_invalidmaillist'] = 'Invalid mailing list name: "<b>$VAR[0]</b>"';
$lang_text['ml_err_invalidpassword'] = 'The password can not contain space symbol.';
$lang_text['ml_err_maxml'] = 'You have reached the maximum number of mailing lists. You cannot set up any more mailing lists.';
$lang_text['ml_err_not_found'] = 'The maillist is not found';
$lang_text['ml_err_passnotmatch'] = 'Passwords do not match';
$lang_text['ml_havend'] = 'You have already set up <b>$VAR[0]</b> mailing lists of a total of <b>$VAR[1]</b> possible mailing lists.';
$lang_text['ml_listcreated'] = 'The mailing list &quot;<b>$VAR[0]</b>&quot; has been set up.';
$lang_text['ml_listcreated_pwd'] = 'The mailing list &quot;<b>$VAR[0]</b>&quot; has been set up. Password is &quot;<b>$VAR[1]</b>&quot;.';
$lang_text['ml_maillistname'] = 'Mailing list name';
$lang_text['ml_majordomo'] = 'MajorCool';
$lang_text['ml_next'] = '[&gt; next]';
$lang_text['ml_owneremail'] = 'Owner e-mail';
$lang_text['ml_password'] = 'Password';
$lang_text['ml_prev'] = '[&lt; prev]';
$lang_text['ml_pwdchanged'] = 'Password has been changed';
$lang_text['ml_search'] = 'Search';
$lang_text['ml_status_new'] = 'new';
$lang_text['ml_status_normal'] = 'ok';
$lang_text['ml_status_todelete'] = 'deleted';
$lang_text['mpop_changepw'] = 'Change password';
$lang_text['mpop_selectlanguage'] = 'Language';
$lang_text['mt_atdomains'] = 'At domains';
$lang_text['mt_auth'] = 'Password protect';
$lang_text['mt_cgicheck'] = 'Perl debugger';
$lang_text['mt_domains'] = 'Domains';
$lang_text['mt_errorfiles'] = 'Error files';
$lang_text['mt_ftpusers'] = 'FTP users';
$lang_text['mt_webftp'] = 'WebFTP';
$lang_text['mt_webmail'] = 'WebMail';
$lang_text['nodb_descr1'] = 'Sorry, this feature is not available to you. Please contact your web-hoster with any questions.';
$lang_text['nodb_title1'] = 'Databases';
$lang_text['noem_descr1'] = 'Sorry, this feature is not available to you. Please contact your web-hoster with any questions.';
$lang_text['noem_title1'] = 'E-mail';
$lang_text['pop_alpw2_error1'] = 'The old password does not match the password on file. Please complete the form again.';
$lang_text['pop_alpw2_error3'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['pop_alpw2_error4'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['pop_alpw2_error5'] = 'Your password has been changed.';
$lang_text['pop_alpw2_errortitle'] = 'Notice:';
$lang_text['pop_alpw_button1'] = 'Change password';
$lang_text['pop_alpw_cell_newpw1'] = 'New password';
$lang_text['pop_alpw_cell_newpw2'] = 'Re-enter password';
$lang_text['pop_alpw_cell_oldpw'] = 'Old password';
$lang_text['pop_alpw_descr1'] = 'Please complete the entire form below and confirm by clicking on &quot;Change password&quot;.';
$lang_text['pop_alpw_title'] = 'Change password';
$lang_text['pop_alsp2_error1'] = 'Invalid language selection. The language has not been changed.';
$lang_text['pop_alsp_button1'] = 'Change';
$lang_text['pop_alsp_descr1'] = 'Select a language and charset encoding for your Confixx web interface.';
$lang_text['pop_alsp_encoding'] = 'Charset encoding';
$lang_text['pop_alsp_title1'] = 'Language';
$lang_text['pop_alst_button1'] = 'Go WebMail!';
$lang_text['pop_alst_descr1'] = 'Click &quot;Go WebMail!&quot;, to access WebMail.';
$lang_text['pop_alst_title'] = 'WebMail &quot;$VAR[0]&quot;';
$lang_text['sest_descr1'] = 'Use these tools to make several additional settings.';
$lang_text['sest_descr2'] = 'For example, you can link your domains to other directories or to other Internet addresses. To make these domain settings, simply select <b>&quot;Domains&quot;</b> from the menu.';
$lang_text['sest_title1'] = 'Settings';
$lang_text['spam_accept'] = 'Accept';
$lang_text['spam_addr_mod'] = 'Edit address';
$lang_text['spam_addr_new'] = 'Add New Address';
$lang_text['spam_adv_mode'] = 'For advanced users';
$lang_text['spam_cell_comment'] = 'Comment';
$lang_text['spam_cell_pop3'] = 'POP3-Postfach';
$lang_text['spam_config_desc'] = '<b>Required Hits</b> Once all SpamAssassin tests have been run, the resulting score is matched against this value, and if greater than this value, the e-mail message is marked as spam.
The default value for Required Hits is 5, which is quite aggressive. A value of 10 will produce less false positives. The average SPAM score is around 15 to 16.<br>
<b>Rewrite Subject Line</b> SpamAssassin will re-write the subject line of your e-mail that has detected to be spam by prefixing the original subject with: *****SPAM*****. To turn off this feature, un-check this option.<br>
<b>Report in Header</b> SpamAssassin will create a report when it detects an e-mail message to be spam. This report is normaly prepended to the e-mail message. To have the report written as part of the e-mail header, select this option.';
$lang_text['spam_defang_mime'] = 'De-HTML Spam';
$lang_text['spam_defang_mime_desc'] = 'When a e-mail in HTML format is detected as Spam, the SpamAssassin will convert the message to text. To keep the e-mail in it\'s original HTML form, de-select this option.';
$lang_text['spam_deny'] = 'Deny';
$lang_text['spam_desc1'] = 'Configure Spam filter.';
$lang_text['spam_desc2'] = 'Configure Spam filter for $VAR[0].';
$lang_text['spam_desc3'] = 'Below is your list of sender addresses that are either Allowed or Denied passage regardless of the Spam score.';
$lang_text['spam_desc3_action'] = 'Action';
$lang_text['spam_desc3_mail'] = 'E-Mail';
$lang_text['spam_desc3_type'] = 'Type';
$lang_text['spam_email_removed'] = 'Address Removed';
$lang_text['spam_error0'] = 'Error: You must include an e-mail address.';
$lang_text['spam_error1'] = 'Error: invalid e-mail address.';
$lang_text['spam_error2'] = 'Error: You must select Allow or Drop!';
$lang_text['spam_error3'] = 'Error: Duplicate address.';
$lang_text['spam_general_sett'] = 'General Settings';
$lang_text['spam_link_change'] = 'Change';
$lang_text['spam_max_hits'] = 'Required Hits';
$lang_text['spam_max_hits_desc'] = 'Once all SpamAssassin tests have been run, the resulting score is matched against this value, and if greater than this value, the e-mail message is marked as spam.';
$lang_text['spam_max_hits_desc2'] = 'The default value for Required Hits is 5, which is quite aggressive. A value of 10 will produce less false positives. The average SPAM score is around 15 to 16.';
$lang_text['spam_modify'] = 'Modify';
$lang_text['spam_remove'] = 'Remove';
$lang_text['spam_report_header'] = 'Report in Header';
$lang_text['spam_report_header_desc'] = 'SpamAssassin will create a report when it detects an e-mail message to be spam. This report is normaly prepended to the e-mail message. To have the report written as part of the e-mail header, select this option.';
$lang_text['spam_rewrite_subject'] = 'Rewrite Subject Line';
$lang_text['spam_rewrite_subject_desc'] = 'SpamAssassin will re-write the subject line of your e-mail that has detected to be spam by prefixing the original subject with: *****SPAM*****. To turn off this feature, un-check this option.';
$lang_text['spam_rewrite_subject_sa3x'] = 'Rewrite Subject Line';
$lang_text['spam_rewrite_subject_sa3x_desc'] = 'SpamAssassin will rewrite the subject of your email that has detected to be spam by prefixing the original subject by string that you enter. You can use _SCORE_ and _REQD_ tags in this string. To turn off this feature, use empty string.';
$lang_text['spam_simple_mode'] = 'Simple mode';
$lang_text['spam_title'] = 'Spam filter';
$lang_text['spam_title3'] = 'Allow / Deny Addresses List';
$lang_text['spam_update'] = 'Update settings';
$lang_text['spam_use_terse_report'] = 'Short Report';
$lang_text['spam_use_terse_report_desc'] = 'This options will tell SpamAssassin to use a shorter Spam report once the message has been found to be spam.';
$lang_text['toba_desc1'] = 'You can select which sections you want to backup.<br><br>You can select between html (your web-data), files (your "files"-directory) and mysql (your MySQL-databases).<br><br>The files (html.tar.gz, files.tar.gz, mysql.tar.gz) can be downloaded via FTP from the "backup"-directory! It may take a few minutes, until you can see the files.<br><br>The files can be opened with Winzip.';
$lang_text['tobk_apply'] = 'Apply';
$lang_text['tobk_backup'] = 'Backup';
$lang_text['tobk_check'] = 'Check connection';
$lang_text['tobk_download'] = 'restore download from';
$lang_text['tobk_err_chdir'] = 'Can\'t change dir to \'$VAR[0]\'';
$lang_text['tobk_err_connect'] = 'Can\'t connect to ftp server \'$VAR[0]\'';
$lang_text['tobk_err_login'] = 'User \'$VAR[0]\' can\'t login with password \'$VAR[1]\'';
$lang_text['tobk_err_no_paswd'] = 'Settings of user is not aplied yet. You can\'t see date of backups. Please wait...';
$lang_text['tobk_err_url'] = 'URL is not valid or not set';
$lang_text['tobk_help'] = 'Specify URL as ftp://[user]@[host.domen]/[path]';
$lang_text['tobk_login_success'] = 'User \'$VAR[0]\' is loged successfull to ftp server \'$VAR[1]\'';
$lang_text['tobk_opts_desc'] = 'Backup/Restore settings';
$lang_text['tobk_paswd'] = 'Password';
$lang_text['tobk_restore'] = 'Restore';
$lang_text['tobk_state_idle'] = 'idle';
$lang_text['tobk_state_sheduled'] = 'sheduled';
$lang_text['tobk_ttl_date'] = 'Date';
$lang_text['tobk_ttl_dest'] = 'Destination';
$lang_text['tobk_ttl_download'] = 'Download';
$lang_text['tobk_ttl_size'] = 'Size';
$lang_text['tobk_ttl_source'] = 'Source';
$lang_text['tobk_ttl_state'] = 'Status';
$lang_text['tobk_ttl_upload'] = 'Upload';
$lang_text['tobk_upload'] = 'backup upload to';
$lang_text['tobk_url'] = 'URL';
$lang_text['tocg_cell_dir'] = 'Directory/file';
$lang_text['tocg_cell_script'] = 'Perl script';
$lang_text['tocg_check'] = 'check...';
$lang_text['tocg_desc1'] = 'In this section you can check your Perl scripts for errors. Please select a script and click &quot;Check...&quot;.';
$lang_text['tocg_title'] = 'Perl debugger';
$lang_text['tocg_title2'] = 'Perl debugger reports:';
$lang_text['todo_btn_save'] = 'Save';
$lang_text['todo_catch_changed'] = 'Status of catch is changed';
$lang_text['todo_catch_switch_off'] = 'The domain is the catch. Click to turn off catch.';
$lang_text['todo_catch_switch_on'] = 'The domain is not the catch. Click to turn on catch.';
$lang_text['todo_cell_action'] = 'Action';
$lang_text['todo_cell_catch'] = 'Catch';
$lang_text['todo_cell_domain'] = 'Domain';
$lang_text['todo_cell_path'] = 'Target';
$lang_text['todo_cell_redirect'] = 'Forward to';
$lang_text['todo_cell_ssl'] = 'SSL';
$lang_text['todo_cell_ssl_redirect'] = 'http:// -> https://';
$lang_text['todo_cell_state'] = 'S';
$lang_text['todo_cell_subdomain'] = 'Sub-domain';
$lang_text['todo_confirm_delete'] = 'Would you like to delete this domain?';
$lang_text['todo_desc1'] = 'You have already created <b>$VAR[0]</b> sub-domains.';
$lang_text['todo_desc1a'] = 'There is <b>no limit</b> to the number of sub-domains that can be created.';
$lang_text['todo_desc1b'] = 'You can create a maximum of <b>$VAR[0]</b> additional sub-domains.';
$lang_text['todo_desc2'] = '<b><i>Notice:</i></b> If your domains point to an Internet address and if this Internet address is a direct domain name or a directory, you must insert a &quot;/&quot; at the end.';
$lang_text['todo_desc3'] = 'The directory &quot;<b>/</b>&quot; is your main directory on the server. The directory &quot;/folder&quot; is a sub-directory in your main directory. <b>The specified directory must already be in existence.</b> You can also link your domain(s) to a different Internet page (http://...).';
$lang_text['todo_desc4'] = 'If you enter &quot;<b>*.domain.de</b>&quot; as a sub-domain, any call-ups to your domain will be forwarded to the directory you have specified.';
$lang_text['todo_link_change'] = 'change';
$lang_text['todo_link_del'] = 'delete';
$lang_text['todo_nodomain'] = 'You don\'t have a domain to create sub-domains.';
$lang_text['todo_ssl_changed'] = 'Status of SSL is changed';
$lang_text['todo_ssl_switch_off'] = 'SSL is on for the domain. Click to turn off SSL.';
$lang_text['todo_ssl_switch_off_redir'] = 'http:// -> https:// redirection is on. Click to turn it off.';
$lang_text['todo_ssl_switch_on'] = 'SSL is off for the domain. Click to turn on SSL.';
$lang_text['todo_ssl_switch_on_redir'] = 'http:// -> https:// redirection is off. Click to turn it on.';
$lang_text['todo_subtitle1'] = 'The following domain rules have been specified for your domains.';
$lang_text['todo_subtitle2'] = 'The following sub-domains have been created. ';
$lang_text['todo_subtitle3'] = 'Create sub-domain';
$lang_text['todo_title'] = 'Managing domains';
$lang_text['todoae2_error1'] = 'This domain does not exist.';
$lang_text['todoae2_error10'] = 'A new path has been assigned to domain <b>$VAR[0]</b>.';
$lang_text['todoae2_error11'] = 'Notice:';
$lang_text['todoae2_error2'] = 'You may not use spaces.';
$lang_text['todoae2_error3'] = 'You must enter a path.';
$lang_text['todoae2_error4'] = 'The directory name may only contain letters, numbers and underscores. The special characters tilde (~), period (.) and hyphen (-) can be used as well. These special characters may not be used one after the other. You can move to sub-directories by using a slash (/).';
$lang_text['todoae2_error5'] = 'You must enter a valid path or a valid URL.';
$lang_text['todoae2_error6'] = 'The URL may not contain a backslash (\\).';
$lang_text['todoae2_error7'] = 'The domain may not refer to itself.';
$lang_text['todoae2_error8'] = 'Domain <b>$VAR[0]</b> does not exist.';
$lang_text['todoae2_error9'] = 'At least one domain must point to your main directory <b>/</b> because FrontPage has been activated for you.';
$lang_text['todoae_btn_save'] = 'Save';
$lang_text['todoae_cell_domain'] = 'Domain';
$lang_text['todoae_cell_redirect'] = 'Forward to';
$lang_text['todoae_cell_ssl'] = 'http:// -&gt; https://';
$lang_text['todoae_desc'] = 'You can point the domain <b>$VAR[0]</b> to a different directory in your HTML directory or to another URL.';
$lang_text['todoae_title'] = 'Managing domains';
$lang_text['todolo_error1'] = 'This domain does not exist.';
$lang_text['todolo_error2'] = 'You must first delete all e-mail addresses that you have created with this sub-domain.';
$lang_text['todolo_error3'] = 'You cannot delete this domain. There must be at least one domain pointing to your main directory <b>/</b>.';
$lang_text['todolo_error4'] = 'Sub-domain <b>$VAR[0]</b> has been deleted.';
$lang_text['todolo_error5'] = 'Notice:';
$lang_text['todolo_title1'] = 'Delete sub-domains';
$lang_text['todone_dir_create'] = 'Dir <b>$VAR[0]</b> is not exists. Create?';
$lang_text['todone_domain_skip'] = 'Sub-doman <b>$VAR[0]</b> is not created';
$lang_text['todone_err_not_dir'] = 'Path <b>$VAR[0]</b> exists and is not a dir.';
$lang_text['todone_error1'] = 'You are not authorized to create additional sub-domains.';
$lang_text['todone_error10'] = 'Domain <b>$VAR[0]</b> does not exist.';
$lang_text['todone_error11'] = 'This sub-domain already exists.';
$lang_text['todone_error12'] = 'Sub-domain <b>$VAR[0]</b> has been created.';
$lang_text['todone_error13'] = 'Notice:';
$lang_text['todone_error14'] = 'You can\'t create wildcard sub-domain on shared domain.';
$lang_text['todone_error2'] = 'Please use only letters and numbers in the sub-domain. Hyphens and periods can be used as long they are not used one after the other. Periods and hyphens may not be used at the beginning or at the end.';
$lang_text['todone_error3'] = 'You are not authorized to create an additional catch-all sub-domain.';
$lang_text['todone_error4'] = 'This domain does not exist.';
$lang_text['todone_error5'] = 'You may not use spaces.';
$lang_text['todone_error6'] = 'You must enter a path or URL.';
$lang_text['todone_error7'] = 'You must enter a valid path or a valid URL.';
$lang_text['todone_error8'] = 'The directory may only contain letters and numbers. The special characters tilde (~), period (.) and hyphen (-) can be used as well. These special characters may not be used one after the other. You can move to sub-directories by using a slash (/).';
$lang_text['todone_error9'] = 'The URL may not contain a backslash (\\).';
$lang_text['tofe_cell_action'] = 'Action';
$lang_text['tofe_cell_dir'] = 'Directory';
$lang_text['tofe_desc1'] = 'In this section you can create error files for your domain. These are shown if, for example, a file you want to call up from your web browser could not be found (Error 404).';
$lang_text['tofe_desc2'] = 'You can specify an error file for every directory. The settings will also apply to the sub-directories unless a special error file has been specified for a directory.';
$lang_text['tofe_link_del'] = 'delete';
$lang_text['tofe_link_edit'] = 'change';
$lang_text['tofe_link_new'] = 'create';
$lang_text['tofe_title'] = 'Error files';
$lang_text['tofeae2_error1'] = 'Please enter an error file for at least one type of error.';
$lang_text['tofeae2_error2'] = 'The URL or the path to error file 404 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofeae2_error3'] = 'The path to error file 401 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofeae2_error4'] = 'The URL or the path to error file 500 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofeae2_error5'] = 'The error files have been changed.';
$lang_text['tofeae2_error6'] = 'The URL or the path to error file 403 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofeae2_errortitle'] = 'Notice:';
$lang_text['tofeae_btn_del'] = 'Delete now.';
$lang_text['tofeae_btn_send'] = 'Update';
$lang_text['tofeae_cell_del'] = 'Delete error files for this directory';
$lang_text['tofeae_cell_dir'] = 'Directory';
$lang_text['tofeae_cell_error'] = 'Error';
$lang_text['tofeae_cell_key'] = 'Label';
$lang_text['tofeae_cell_value'] = 'Value';
$lang_text['tofeae_desc1'] = 'Use the form below to make changes to the error files for the directory &quot;$VAR[0]&quot;. Error files for a new directory can be specified <a class=data href="tools_fehlerseiten.php">here</a>.';
$lang_text['tofeae_desc2'] = '<b>Notice:</b> You can specify either a URL (e.g., http://www...) or a file name (e.g.: /Error404.htm). You cannot enter a URL for error 401. You must enter a file name for this error.';
$lang_text['tofeae_subtitle'] = 'Edit error files for &quot;$VAR[0]&quot;';
$lang_text['tofeae_subtitle1'] = 'Edit error files for &quot;$VAR[0]&quot;';
$lang_text['tofeae_title'] = 'Edit error files';
$lang_text['tofelo_error1'] = 'Directory &quot;$VAR[0]&quot; will now display the standard error files.';
$lang_text['tofelo_errortitle'] = 'Notice:';
$lang_text['tofene2_error1'] = 'You must enter a directory.';
$lang_text['tofene2_error10'] = 'Unable to locate or protect directory <b>$VAR[0]</b>. Please select a different directory.';
$lang_text['tofene2_error11'] = 'The URL or the path to error file 403 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofene2_error2'] = 'You must enter a valid directory.';
$lang_text['tofene2_error3'] = 'The directory may only contain letters and numbers. The special characters tilde (~), period (.) and hyphen (-) can be used as well. These special characters may not be used one after the other. You can move to sub-directories by using a slash (/).';
$lang_text['tofene2_error4'] = 'Please enter an error file for at least one type of error.';
$lang_text['tofene2_error5'] = 'The URL or the path to error file 404 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofene2_error6'] = 'The path to error file 401 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofene2_error7'] = 'The URL or the path to error file 500 is not correct. If you do not wish to specify an error file for this error, please leave this field blank.';
$lang_text['tofene2_error8'] = 'Error files have already been defined for this directory.';
$lang_text['tofene2_error9'] = 'The error files have been defined.';
$lang_text['tofene2_errortitle'] = 'Notice:';
$lang_text['tofene_btn_send'] = 'Update';
$lang_text['tofene_cell_action'] = 'Action';
$lang_text['tofene_cell_dir'] = 'Directory';
$lang_text['tofene_cell_error'] = 'Error';
$lang_text['tofene_cell_key'] = 'Label';
$lang_text['tofene_cell_value'] = 'Value';
$lang_text['tofene_desc1'] = '<b>Notice:</b> You can specify either a URL (e.g., http://www...) or a file name (e.g.: /Error404.htm). You cannot enter a URL for error 401. You must enter a file name for this error.';
$lang_text['tofene_subtitle'] = 'Define error files for a directory';
$lang_text['tofene_title'] = 'Error files';
$lang_text['toft_btn_login'] = 'Login';
$lang_text['toft_btn_new'] = 'Create';
$lang_text['toft_cell_action'] = 'Action';
$lang_text['toft_cell_dir'] = 'Directory';
$lang_text['toft_cell_new'] = 'new user';
$lang_text['toft_cell_user'] = 'User';
$lang_text['toft_confirm_delete'] = 'Would you like to delete FTP user $VAR[0]?';
$lang_text['toft_desc1'] = 'Create additional FTP users and assign a subdirectory in your HTML directory to these new FTP users. The directory must already be in existence.';
$lang_text['toft_desc2'] = 'You have already created <b>$VAR[0]</b> FTP users.';
$lang_text['toft_desc2a'] = 'There is <b>no limit</b> to the number of FTP users that can be created.';
$lang_text['toft_desc2b'] = 'You can create a maximum of <b>$VAR[0]</b> additional FTP users.';
$lang_text['toft_link_change'] = 'Change password';
$lang_text['toft_link_del'] = 'Delete user';
$lang_text['toft_subtitle1'] = 'The following FTP users have been entered';
$lang_text['toft_subtitle2'] = 'Create FTP user';
$lang_text['toft_title'] = 'FTP users';
$lang_text['toft_title1'] = 'Login to WebFTP as main user.';
$lang_text['toftlo_error1'] = 'This FTP account does not exist.';
$lang_text['toftlo_error2'] = 'FTP user &quot;<b>$VAR[0]</b>&quot; has been deleted. \'Directory &quot;<b>$VAR[1]</b>&quot; may now be deleted.';
$lang_text['toftlo_errortitle'] = 'Notice:';
$lang_text['toftne_error1'] = 'Unable to locate directory <b>$VAR[0]</b>. Please correct the path.';
$lang_text['toftne_error2'] = 'No additional FTP users can be created for directory <b>$VAR[0]</b>.';
$lang_text['toftne_error3'] = 'You are not authorized to create additional FTP users.';
$lang_text['toftne_error4'] = 'The FTP account could not be created because the account name could not be determined. Please try again.';
$lang_text['toftne_error5'] = 'The FTP user &quot;<b>$VAR[0]</b>&quot; has been created. Your password is &quot;<b>$VAR[1]</b>&quot;. The new FTP user can use these access data to log onto this Confixx interface, change the user password and use WebFTP.';
$lang_text['toftne_error6'] = 'The home directory name can not contain ":" symbol.';
$lang_text['toftne_errortitle'] = 'Notice:';
$lang_text['toftpw2_error2'] = 'The two new passwords do not match. Please complete the form again.';
$lang_text['toftpw2_error3'] = 'Your password must consist of at least 6 characters and no more than 12 characters. Please complete the form again.';
$lang_text['toftpw2_error4'] = 'Notice:';
$lang_text['toftpw2_error5'] = 'The password for the FTP user has been changed.';
$lang_text['toftpw_btn_change'] = 'Change password';
$lang_text['toftpw_cell_pw1'] = 'New password';
$lang_text['toftpw_cell_pw2'] = 'Re-enter password';
$lang_text['toftpw_cell_title'] = 'FTP users';
$lang_text['toftpw_desc1'] = 'Please complete the entire form and confirm by clicking on &quot;Change password&quot;.';
$lang_text['toftpw_title'] = 'Change FTP user password';
$lang_text['topw_cell_action'] = 'Action';
$lang_text['topw_cell_dir'] = 'Directory';
$lang_text['topw_desc1'] = 'In this section you can protect the directories and folders of your Internet page with a username and a password.';
$lang_text['topw_desc2'] = 'Click on a directory name to get a listing of the sub-directories.';
$lang_text['topw_link_edit'] = 'edit';
$lang_text['topw_link_protect'] = 'protect';
$lang_text['topw_title'] = 'Password protection';
$lang_text['topwae2_error1'] = 'You must enter a directory.';
$lang_text['topwae2_error2'] = 'Unable to locate or protect directory <b>$VAR[0]</b>. Please select a different directory.';
$lang_text['topwae2_error3'] = 'Please only use letters, numbers and spaces. You can enter up to 20 characters.';
$lang_text['topwae2_error4'] = 'The new directory has already been furnished with a password.';
$lang_text['topwae2_error5'] = 'The data have been changed.';
$lang_text['topwae2_errortitle'] = 'Notice:';
$lang_text['topwae_btn_change'] = 'Apply';
$lang_text['topwae_btn_del'] = 'Remove all users';
$lang_text['topwae_btn_new'] = 'Create';
$lang_text['topwae_cell_action'] = 'Action';
$lang_text['topwae_cell_area'] = 'Section:';
$lang_text['topwae_cell_dir'] = 'Directory:';
$lang_text['topwae_cell_login'] = 'Login:';
$lang_text['topwae_cell_pw1'] = 'Password:';
$lang_text['topwae_cell_pw2'] = 'Re-enter password:';
$lang_text['topwae_cell_user'] = 'User';
$lang_text['topwae_link_change'] = 'Change password';
$lang_text['topwae_link_del'] = 'delete';
$lang_text['topwae_subtitle1'] = 'Information about the protected directory:';
$lang_text['topwae_subtitle2'] = 'Users who have access to this directory: ';
$lang_text['topwae_subtitle3'] = 'Add new user:';
$lang_text['topwae_subtitle4'] = 'Remove password protection for this directory:';
$lang_text['topwae_title'] = 'Password protect';
$lang_text['topwau_error1'] = 'Directory protection has been deleted.';
$lang_text['topwau_errortitle'] = 'Notice:';
$lang_text['topwlo_error1'] = 'You cannot delete this user. There must be at least one user.';
$lang_text['topwlo_error2'] = 'User has been deleted.';
$lang_text['topwlo_errortitle'] = 'Notice:';
$lang_text['topwnb_error1'] = 'Login may only consist of letters, numbers and spaces with no more than 35 characters.';
$lang_text['topwnb_error2'] = 'The password must consist of at least 6 characters and no more than 12 characters.';
$lang_text['topwnb_error3'] = 'The two passwords do not match.';
$lang_text['topwnb_error4'] = 'Login for this directory already exists.';
$lang_text['topwnb_error5'] = 'Login has been created.';
$lang_text['topwnb_errortitle'] = 'Notice:';
$lang_text['topwne2_error1'] = 'You must enter a directory.';
$lang_text['topwne2_error2'] = 'Unable to locate or protect directory <b>$VAR[0]</b>. Please select a different directory.';
$lang_text['topwne2_error3'] = 'The section name may only consist of letters, numbers and spaces with no more than 20 characters.';
$lang_text['topwne2_error4'] = 'Login may only consist of letters, numbers and spaces with no more than 35 characters.';
$lang_text['topwne2_error5'] = 'The password must consist of at least 6 characters and no more than 12 characters.';
$lang_text['topwne2_error6'] = 'The two passwords do not match.';
$lang_text['topwne2_error7'] = 'The directory has already been protected with a password.';
$lang_text['topwne2_error8'] = 'The directory has been protected with a password.';
$lang_text['topwne2_errortitle'] = 'Notice:';
$lang_text['topwne_btn_do'] = 'Update';
$lang_text['topwne_cell_area'] = 'Section name';
$lang_text['topwne_cell_dir'] = 'Directory';
$lang_text['topwne_cell_key'] = 'Label';
$lang_text['topwne_cell_login'] = 'Login';
$lang_text['topwne_cell_pw1'] = 'Password';
$lang_text['topwne_cell_pw2'] = 'Re-enter password';
$lang_text['topwne_cell_value'] = 'Value';
$lang_text['topwne_subtitle'] = '<b>Password-protect new directory:</b>';
$lang_text['topwne_title'] = 'Password protection';
$lang_text['topwpw2_error1'] = 'The password must consist of at least 6 characters and no more than 12 characters.';
$lang_text['topwpw2_error2'] = 'The two passwords do not match.';
$lang_text['topwpw2_error3'] = 'Password has been changed.';
$lang_text['topwpw2_errortitle'] = 'Notice:';
$lang_text['topwpw_btn_change'] = 'Apply changes';
$lang_text['topwpw_cell_pw1'] = 'Password:';
$lang_text['topwpw_cell_pw2'] = 'Re-enter password:';
$lang_text['topwpw_cell_user'] = 'User:';
$lang_text['topwpw_subtitle'] = 'Change password';
$lang_text['topwpw_title'] = 'Password protection';
$lang_text['tore_desc1'] = 'You can select which sections you want to restore.<br><br>You can select between html (your web-data), files (your "files"-directory) and mysql (your MySQL-databases).<br><br>The files (html.tar.gz, files.tar.gz, mysql.tar.gz) must be uploaded before via FTP into the "restore"-directory!';
$lang_text['torst_from_backup'] = 'Get dumps from ~/backup';
$lang_text['tost_desc1'] = 'Here are some additional tools  you can use.';
$lang_text['tost_desc2'] = 'For example, you can make backup of your website content and databases.';
$lang_text['tost_title'] = 'Confixx tools';
$lang_text['towe_btn_go'] = 'Go WebFTP!';
$lang_text['towe_cell_ftp'] = 'FTP access';
$lang_text['towe_cell_pw'] = 'Password';
$lang_text['towe_desc1'] = 'WebFTP is an interface used to upload and download files using FTP from your browser.';
$lang_text['towe_desc2'] = 'Select your FTP account and enter your password to access WebFTP.';
$lang_text['towe_title'] = 'WebFTP';
$lang_text['towem_btn_go'] = 'Go WebMail!';
$lang_text['towem_cell_account'] = 'Mail box';
$lang_text['towem_cell_pw'] = 'Password';
$lang_text['towem_desc1'] = 'Use WebMail to send and receive e-mails without using an e-mail program.';
$lang_text['towem_desc2'] = 'Select your POP3 box and enter your password to access WebMail.';
$lang_text['towem_desc3'] = 'You do not have any POP3 boxes from which you could retrieve e-mails.';
$lang_text['towem_title'] = 'WebMail';
$lang_text['wa_action'] = 'Action';
$lang_text['wa_admin_email'] = 'E-mail';
$lang_text['wa_admin_err_passwds'] = 'Admin\'s passwords do not match';
$lang_text['wa_admin_login'] = 'Login name';
$lang_text['wa_admin_name'] = 'Name';
$lang_text['wa_admin_options'] = 'Admin options';
$lang_text['wa_admin_passwd'] = 'Password';
$lang_text['wa_admin_passwd2'] = 'Re-enter password';
$lang_text['wa_admin_path'] = 'Path to install';
$lang_text['wa_all_types'] = 'All';
$lang_text['wa_app_description'] = 'Description';
$lang_text['wa_app_language'] = 'Language';
$lang_text['wa_app_name'] = 'Name';
$lang_text['wa_app_options'] = 'Application';
$lang_text['wa_app_path'] = 'Path to install';
$lang_text['wa_conf'] = 'Configure';
$lang_text['wa_config'] = 'Config';
$lang_text['wa_config_head'] = 'Configure';
$lang_text['wa_db_clean'] = 'Clean database';
$lang_text['wa_db_create'] = 'Create new database';
$lang_text['wa_db_err_emprty_passwd'] = 'Error: database password is not set';
$lang_text['wa_db_err_passwd'] = 'Error: wrong database password';
$lang_text['wa_db_name'] = 'Name';
$lang_text['wa_db_options'] = 'Database options';
$lang_text['wa_db_password'] = 'Password';
$lang_text['wa_db_user'] = 'User';
$lang_text['wa_del_db'] = 'Clean application database \'$VAR[0]\'?';
$lang_text['wa_del_descr'] = 'Uninstall application \'$VAR[0]\'?';
$lang_text['wa_del_path'] = 'Remove application directory \'$VAR[0]\'?';
$lang_text['wa_del_title'] = 'Uninstallation of the web application';
$lang_text['wa_descr'] = 'Description';
$lang_text['wa_domain'] = 'Domain';
$lang_text['wa_header_login'] = 'Login name';
$lang_text['wa_header_options'] = 'Header options';
$lang_text['wa_header_passwd'] = 'Password';
$lang_text['wa_header_passwd2'] = 'Re-enter password';
$lang_text['wa_install'] = 'Install';
$lang_text['wa_install_error'] = 'You have installed the maximum number of web applications. You cannot install any more web applications.';
$lang_text['wa_mambo_editor_login'] = 'Login name';
$lang_text['wa_mambo_editor_options'] = 'Mambo editor';
$lang_text['wa_mambo_editor_passwd'] = 'Password';
$lang_text['wa_mambo_editor_passwd2'] = 'Re-enter password';
$lang_text['wa_name'] = 'Name';
$lang_text['wa_persinfo_city'] = 'City';
$lang_text['wa_persinfo_company'] = 'Company';
$lang_text['wa_persinfo_email'] = 'Email';
$lang_text['wa_persinfo_fax'] = 'Fax';
$lang_text['wa_persinfo_fullname'] = 'Full name';
$lang_text['wa_persinfo_localtion'] = 'Location';
$lang_text['wa_persinfo_options'] = 'Personal information';
$lang_text['wa_setup_login'] = 'Login name';
$lang_text['wa_setup_options'] = 'Setup options';
$lang_text['wa_setup_passwd'] = 'Password';
$lang_text['wa_setup_passwd2'] = 'Re-enter password';
$lang_text['wa_status'] = 'Status';
$lang_text['wa_status_off'] = 'Off';
$lang_text['wa_status_on'] = 'On';
$lang_text['wa_status_to_off'] = 'To off';
$lang_text['wa_status_to_on'] = 'To on';
$lang_text['wa_switch_to_off'] = 'Switch to off';
$lang_text['wa_switch_to_on'] = 'Switch to on';
$lang_text['wa_title'] = 'Web Applications';
$lang_text['wa_type'] = 'Group';
$lang_text['wa_uninstall'] = 'Uninstall';
$lang_text['wa_unkn_options'] = 'Other options';
$lang_text['wa_version'] = 'Version';
$lang_text['wbm_ab_is_empty'] = 'Address Book is empty...';
$lang_text['wbm_ad_actions'] = '<b>Action</b>';
$lang_text['wbm_ad_adbook'] = 'Address Book';
$lang_text['wbm_ad_add'] = 'add';
$lang_text['wbm_ad_delete'] = 'Delete Entry';
$lang_text['wbm_ad_deletemsg'] = '<b>Entries successfully deleted.</b>';
$lang_text['wbm_ad_deletemsg_insecure'] = '<b>Can\'t delete entry.</b>';
$lang_text['wbm_ad_edit'] = 'View/Edit Entry';
$lang_text['wbm_ad_editentry'] = '<b>Entry successfully edited.</b>';
$lang_text['wbm_ad_email'] = '<b>Email-Address</b>';
$lang_text['wbm_ad_emptyrecord'] = '$VAR[0] and $VAR[1] fields should not be empty';
$lang_text['wbm_ad_form_adress'] = 'Address';
$lang_text['wbm_ad_form_fax'] = 'Fax';
$lang_text['wbm_ad_form_firstname'] = 'First Name';
$lang_text['wbm_ad_form_lastname'] = 'Last Name';
$lang_text['wbm_ad_form_name'] = '<b>Formatted Name</b>';
$lang_text['wbm_ad_form_person'] = '<b>Person</b>';
$lang_text['wbm_ad_form_reset'] = 'Reset';
$lang_text['wbm_ad_form_submit'] = 'Enter into Address Book';
$lang_text['wbm_ad_form_tel'] = '<b>Telephone</b>';
$lang_text['wbm_ad_form_telhome'] = 'Home';
$lang_text['wbm_ad_form_telmobile'] = 'Mobile';
$lang_text['wbm_ad_form_telwork'] = 'Work';
$lang_text['wbm_ad_info'] = 'Legend';
$lang_text['wbm_ad_name'] = '<b>Name</b>';
$lang_text['wbm_ad_new'] = 'Add Entry';
$lang_text['wbm_ad_newentry'] = '<b>New entry successfully entered into your Address Book.</b>';
$lang_text['wbm_ad_newmail'] = 'Send Mail to Address Book Entry';
$lang_text['wbm_ad_persadbook'] = 'Your Address Book';
$lang_text['wbm_ad_status0'] = '<b>There are no entries in your Address Book!</b>';
$lang_text['wbm_ad_status1'] = '<b>There is one entry in your Address Book:</b>';
$lang_text['wbm_ad_status2'] = 'There are $VAR[0] entries in your Address Book';
$lang_text['wbm_ad_to_adbook'] = 'Add to address Book';
$lang_text['wbm_adb_export'] = 'Export';
$lang_text['wbm_adb_import'] = 'Import';
$lang_text['wbm_adb_import_bad'] = 'File was uploaded but not processed!';
$lang_text['wbm_adb_import_form'] = 'Import form';
$lang_text['wbm_adb_import_successfull'] = 'Address book is successfully imported!';
$lang_text['wbm_answered'] = 'Answered';
$lang_text['wbm_attach'] = 'Attachment';
$lang_text['wbm_attachment'] = 'Attachment';
$lang_text['wbm_back_to_list'] = 'Back to list';
$lang_text['wbm_bcc'] = 'BCC';
$lang_text['wbm_body'] = 'Body';
$lang_text['wbm_buttonnext'] = '&raquo; continue';
$lang_text['wbm_cc'] = 'CC';
$lang_text['wbm_confirm_delete'] = 'Would you like to delete selected message(s)?';
$lang_text['wbm_confirm_delete_one'] = 'Would you like to delete this message?';
$lang_text['wbm_date'] = 'Date';
$lang_text['wbm_deffrom_ok'] = 'Default Alias Changed ';
$lang_text['wbm_deffrom_set'] = 'set as default alias';
$lang_text['wbm_deffrom_status'] = 'Default alias successfully set to $VAR[0]';
$lang_text['wbm_delete'] = 'Delete';
$lang_text['wbm_delete_msg1'] = '<b>Email %numMessages% was deleted.</b>';
$lang_text['wbm_delete_msg2'] = '<b>Emails %numMessages% were deleted..</b>';
$lang_text['wbm_delete_nomsg'] = '<b>Please choose which of the emails you\'d like to delete.</b>';
$lang_text['wbm_email_del'] = 'Delete';
$lang_text['wbm_email_download'] = 'Download';
$lang_text['wbm_email_fwd'] = 'Forward';
$lang_text['wbm_email_print'] = 'Print';
$lang_text['wbm_email_reply'] = 'Reply';
$lang_text['wbm_email_reply_all'] = 'Reply to All';
$lang_text['wbm_email_unsubscribe'] = 'Unsubscribe';
$lang_text['wbm_email_viewsource'] = 'View Source';
$lang_text['wbm_form_reset'] = 'Reset';
$lang_text['wbm_form_submit'] = 'Set';
$lang_text['wbm_forwarded_message'] = 'Forwarded message';
$lang_text['wbm_from'] = 'From';
$lang_text['wbm_fwdzitat'] = 'On %date% at %time%, %sender% wrote:';
$lang_text['wbm_getad'] = 'from Address Book...';
$lang_text['wbm_import_close'] = 'Close';
$lang_text['wbm_import_file'] = 'File for import';
$lang_text['wbm_import_send'] = 'Send';
$lang_text['wbm_message_encoding'] = 'Message charset encoding';
$lang_text['wbm_message_warning'] = 'Can\'t find the message!';
$lang_text['wbm_msg_htmlalert'] = '<b>Please note:</b> because of security concerns the text version of this message is shown.';
$lang_text['wbm_msg_htmlshow'] = 'View HTML-version.';
$lang_text['wbm_msglist_desc'] = '<b>You have $VAR[0] unread of $VAR[1] messages</b>';
$lang_text['wbm_msglist_desc2'] = '<b>You have $VAR[0] messages</b>';
$lang_text['wbm_msglist_nomails'] = '<b>There are currently no emails in your mailbox.</b>';
$lang_text['wbm_msglist_select'] = 'de/activate all ';
$lang_text['wbm_msglist_selected'] = 'Chosen emails:';
$lang_text['wbm_msglist_status'] = '<b>E-mails $VAR[0] of $VAR[1]</b>';
$lang_text['wbm_new'] = 'New';
$lang_text['wbm_nomessages_selected'] = 'Please, select one or more message(s) to delete';
$lang_text['wbm_nospam'] = 'Ham';
$lang_text['wbm_nosubject'] = 'No Subject';
$lang_text['wbm_prio'] = 'Priority';
$lang_text['wbm_prio_high'] = 'High';
$lang_text['wbm_prio_low'] = 'Low';
$lang_text['wbm_prio_normal'] = 'Normal';
$lang_text['wbm_quickadd'] = 'Quick Add';
$lang_text['wbm_recipient'] = 'To';
$lang_text['wbm_rezitat'] = 'On %date% at %time%, you wrote:';
$lang_text['wbm_save_as_draft'] = 'Save as draft';
$lang_text['wbm_save_whitelist'] = 'Save';
$lang_text['wbm_sender'] = 'From';
$lang_text['wbm_sendmail_addtoab'] = 'Add this e-mail ($VAR[0]) to my address book';
$lang_text['wbm_sendmail_error'] = 'Sending email failed:';
$lang_text['wbm_sendmail_norecipient'] = '<b>Error:</b> Please specify recipient.';
$lang_text['wbm_sendmail_ok'] = 'You have just sent this email:';
$lang_text['wbm_show'] = 'Show';
$lang_text['wbm_show_all'] = 'Show all messages';
$lang_text['wbm_show_nospam'] = 'Show nospam messages only';
$lang_text['wbm_show_page100'] = '100 messages per page';
$lang_text['wbm_show_page20'] = '20 messages per page';
$lang_text['wbm_show_page50'] = '50 messages per page';
$lang_text['wbm_show_pageall'] = 'all messages on the page';
$lang_text['wbm_show_spam'] = 'Show spam messages only';
$lang_text['wbm_show_spam2'] = 'Show spam messages';
$lang_text['wbm_sign_add'] = 'Signature';
$lang_text['wbm_sign_alias'] = 'Signature for alias $VAR[0]';
$lang_text['wbm_sign_change'] = 'Signature for alias successfully set to $VAR[0]';
$lang_text['wbm_sign_edit'] = 'View/edit signature';
$lang_text['wbm_sign_showedit'] = 'View/edit';
$lang_text['wbm_signature'] = 'Signature';
$lang_text['wbm_size'] = 'Size';
$lang_text['wbm_spam'] = 'Spam';
$lang_text['wbm_status'] = 'S';
$lang_text['wbm_subject'] = 'Subject';
$lang_text['wbm_text'] = 'Text';
$lang_text['wbm_to'] = 'To';
$lang_text['wbm_total_messages'] = 'Number of messages';
$lang_text['wbm_unknown'] = 'unknown';
$lang_text['wbm_unread'] = 'Unread';
$lang_text['wbm_unread_messages'] = 'Unread messages';
$lang_text['wbm_whitelist_saved'] = 'Saved!';
$lang_text['wbm_whitelist_text'] = 'Add to spam filter<br> whitelist';
$lang_text['wbm_winclose'] = 'Close window';
$lang_text['wftp_actions'] = 'Actions';
$lang_text['wftp_activate'] = 'de/select all files';
$lang_text['wftp_active'] = 'Selected files:';
$lang_text['wftp_back'] = 'Back';
$lang_text['wftp_chdir_failed'] = '<b>Changing Directory into %fullpath% failed.</b>';
$lang_text['wftp_chdir_notfound'] = '<b>Error:</b> No such file: %fullpath%';
$lang_text['wftp_confirm_delete'] = 'Would you like to delete selected files?';
$lang_text['wftp_confirm_deletewithusers'] = 'Would you like to delete selected files? Additional FTP users assigned to selected directories will be deleted also.';
$lang_text['wftp_date'] = 'Date';
$lang_text['wftp_delete'] = 'Delete';
$lang_text['wftp_dir_error'] = '<b>Error:</b> can not delete directory %dir%, check permissions and owner.';
$lang_text['wftp_dir_ok'] = '<b>Directories deleted:</b> ';
$lang_text['wftp_dircontent'] = 'Directory Content';
$lang_text['wftp_direct'] = 'or<br>directly';
$lang_text['wftp_download'] = 'Direct File Download';
$lang_text['wftp_download_error'] = '<b>Error:</b> Could not download %filename%.';
$lang_text['wftp_download_filesize'] = '<b>Error:</b> The size of this file exceeds limit.';
$lang_text['wftp_edit'] = 'Edit File';
$lang_text['wftp_edit_filesize'] = '<b>Error:</b> The size of this file exceeds limit.';
$lang_text['wftp_execute'] = 'Execute';
$lang_text['wftp_file_error'] = '<b>Error:</b> can not delete file %file%, check permissions and owner.';
$lang_text['wftp_file_exists'] = '<b>Error:</b> File %filename% exists already.';
$lang_text['wftp_file_ok'] = '<b>Files deleted:</b> ';
$lang_text['wftp_filename'] = 'Filename';
$lang_text['wftp_fullpath'] = 'Full path';
$lang_text['wftp_group'] = 'Group';
$lang_text['wftp_info'] = '<b>Legend:</b>';
$lang_text['wftp_intopath'] = 'in path';
$lang_text['wftp_mkdir'] = 'Create';
$lang_text['wftp_mkdir_error'] = '<b>Error:</b> Could not create directory <b>&quot;%mkdir%&quot;</b> in <b>&quot;%inDir%&quot;</b>.';
$lang_text['wftp_mkdir_newdir'] = 'Create Directory';
$lang_text['wftp_mkdir_ok'] = 'Created directory <b>%mkdir%</b>.';
$lang_text['wftp_other'] = 'Others';
$lang_text['wftp_owner'] = 'Owner';
$lang_text['wftp_perms'] = 'Permissions';
$lang_text['wftp_props'] = 'File Properties';
$lang_text['wftp_propsfrom'] = 'Properties of';
$lang_text['wftp_read'] = 'Read';
$lang_text['wftp_rename_error'] = '<b>Error:</b> Renaming of <b>%oldName%</b> to <b>%newName%</b> failed.';
$lang_text['wftp_rename_ok'] = '<b>File <b>%oldName%</b> renamed to <b>%newName%</b>.';
$lang_text['wftp_reset'] = 'Reset';
$lang_text['wftp_select_files'] = 'Please, select files to delete';
$lang_text['wftp_setperms_emtpy'] = '<b>Error:</b> You tried to set mode to &quot;000&quot;. Permissions not changed!';
$lang_text['wftp_setperms_error'] = '<b>Error:</b> Setting permissions of <b>%name%</b> failed.';
$lang_text['wftp_setperms_ok'] = 'Permissions of <b>%name%</b> set to <b>%newPerms%</b>.';
$lang_text['wftp_size'] = 'Size';
$lang_text['wftp_submit'] = 'Submit';
$lang_text['wftp_upload'] = 'Upload';
$lang_text['wftp_upload_error'] = '<b>Error:</b> Could not upload file <b>%filename%</b> into <b>%inDir%</b>. Probably you do not have the necessary permissions.';
$lang_text['wftp_upload_file'] = 'File for upload';
$lang_text['wftp_upload_filename'] = 'Remote filename<br>(empty for original)';
$lang_text['wftp_upload_force'] = 'overwrite existing';
$lang_text['wftp_upload_ok'] = 'Uploaded file <b>%filename%</b> into directory <b>%inDir%</b>.';
$lang_text['wftp_write'] = 'Write';
$lang_text['wmail_email'] = '<p><b>There must be at least one existing Email-Address.</b>';
$lang_text['wmail_noiconv'] = 'Can\'t find installed the Iconv library!';
$lang_text['wmail_noimap'] = 'Can\'t find installed the IMAP library!';
$lang_text['wmail_notcreated'] = '<p><b>Your POP3 account was not created yet. It usually takes several minutes to create an account. Please, try again later.</b>';
$lang_text['wmail_pop3'] = '<p><b>Mail server unavailable. Maybe mail service is down at the moment.</b>';
$lang_text['wmb_add_folder'] = 'Add folder';
$lang_text['wmb_edit_folder'] = 'Edit folder';
$lang_text['wmb_send'] = 'Send email';
$lang_text['wmb_zitat'] = 'Quote';

?>
